@@ -5,6 +5,8 @@
 # License: BSD Style.
 
 # Standard library imports
+import gc
+import os
 import os.path
 import sys
 import logging
@@ -13,9 +15,8 @@ from optparse import OptionParser
 
 # Enthought library imports
 from traits.etsconfig.api import ETSConfig
-from traits.api import  Bool, Instance
+from traits.api import  Any, Bool, Instance
 from pyface.api import GUI
-from pyface.timer.api import do_later
 from tvtk.api import tvtk
 from mayavi.plugins.app import Mayavi, setup_logger
 
@@ -39,6 +40,124 @@ def off_screen_viewer():
 class MayaviTestError(Exception):
     pass
 
+###########################################################################
+# `MemoryAssistant` class.
+###########################################################################
+
+class MemoryAssistant(object):
+    """ Assistant methods to assert memory usage and memory leaks.
+    """
+    def assertMemoryUsage(self, process, usage, slack=0, msg=None):
+        """ Assert that the memory usage does not exceed the provided limit.
+
+        Parameters
+        ----------
+        process : psutil.Process
+            The process to check.
+        usage : float
+            The target memory usage. This is used as a soft-limit.
+        msg : str
+            The message to show on AssertionError.
+        slack : float
+            The percentage (relative to `usage`) that we allow the
+            process memory usage to exceed the soft limit. The default is 0.0
+
+        Raises
+        ------
+        AssertionError :
+            if the current memory usage of the process is higher than
+            :math:`usage * (1 + slack)`.
+
+        """
+        current_usage = self._memory_usage(process)
+        hard_limit = usage * (1 + slack)
+        if  hard_limit < current_usage:
+            if msg is None:
+                difference = (current_usage - usage) / usage
+                msg = "Memory leak of {:.2%}".format(difference)
+            raise AssertionError(msg)
+
+    def assertReturnsMemory(self, function, args=None, iterations=100,
+                            slack=0.0, msg=None):
+        """ Assert that the function does not retain memory over a number of
+        runs.
+
+        Parameters
+        ----------
+        func : callable
+            The function to check. The function should take no arguments.
+        args : tuple
+            The tuple of arguments to pass to the callable.
+        iterations : int
+            The number of times to run the function. Default is 100.
+        msg : str
+            The message to show on AssertionError.
+        slack : float
+            The percentage (relative to the first run) that we allow the
+            process memory usage to exceed the expected. The default is 0.0
+
+        Note
+        ----
+        The function is executed in-process thus any memory leaks will be
+        there to cause problems to other tests that are part of the currently
+        running test suite.
+
+        """
+        try:
+            import psutil
+        except ImportError:
+            msg = "Please install psutil to check memory usage"
+            raise ImportError(msg)
+
+        process = psutil.Process(os.getpid())
+
+        def test_function():
+            if args is None:
+                function()
+            else:
+                function(*args)
+
+        gc.collect()
+        baseline = self._memory_usage(process)
+        samples_msg   = "Samples           : {}"
+        mem_usage_msg = "Memory growth (MB): {:5.1f} to {:5.1f}"
+        mem_leak_msg =  "Memory leak   (%) : {:5.1f}"
+
+        try:
+            print 'Profiling',
+            sys.stdout.flush()
+            for index in xrange(iterations):
+                test_function()
+                print '.',
+                sys.stdout.flush()
+                gc.collect()
+                self.assertMemoryUsage(process, baseline, slack=slack)
+            ##########################################
+            # If we have come this far, we are golden!
+            ##########################################
+            final = self._memory_usage(process)
+            leak = (final - baseline) / baseline
+            print
+            print samples_msg.format(index + 1)
+            print mem_usage_msg.format(baseline, final)
+            print mem_leak_msg.format(leak * 100.0, index + 1)
+        except AssertionError:
+            final = self._memory_usage(process)
+            leak = (final - baseline) / baseline
+            if msg is None:
+                msg = 'Memory Leak!!!\n'
+                msg += samples_msg.format(index + 1)
+                msg += '\n'
+                msg += mem_usage_msg.format(baseline, final)
+                msg += '\n'
+                msg += mem_leak_msg.format(leak * 100.0, index + 1)
+                raise AssertionError(msg)
+            else:
+                raise AssertionError(msg)
+
+    def _memory_usage(self, process):
+        return float(process.get_memory_info().rss) / (1024 ** 2)
+
 ######################################################################
 # Image comparison utility functions.
 ######################################################################
@@ -287,6 +406,17 @@ def compare_image(scene, img_path):
         ren.reset_camera()
         s.render()
 
+def is_running_with_nose():
+    """Returns True if we are being run via nosetests.
+
+    This tests if `nosetests` is used or if we are invoked via
+    `python -m nose.core`.
+    """
+    argv0 = sys.argv[0]
+    nose_core = os.path.join('nose', 'core.py')
+    if argv0.endswith('nosetests') or argv0.endswith(nose_core):
+        return True
+    return False
 
 ###########################################################################
 # `TestCase` class.
@@ -304,13 +434,20 @@ class TestCase(Mayavi):
     # `self.compare_image` was called in the test..
     offscreen = Bool(False)
 
-    # Use the standalone mode.
+    # Profile for memory usage.
+    profile = Bool(False)
+
+    # Use the standalone mode. This mode does not use the envisage Mayavi
+    # application.
     standalone = Bool(True)
 
     app_window = Instance('pyface.api.ApplicationWindow')
 
     gui = Instance('pyface.gui.GUI')
 
+    # An exception info if an exception was raised by a test.
+    exception_info = Any
+
     ######################################################################
     # `Mayavi` interface.
     ######################################################################
@@ -321,7 +458,8 @@ class TestCase(Mayavi):
         if argv is None:
             argv = sys.argv[1:]
 
-        self.parse_command_line(argv)
+        if not is_running_with_nose():
+            self.parse_command_line(argv)
 
         if self.standalone:
             self.run_standalone()
@@ -335,6 +473,9 @@ class TestCase(Mayavi):
             path = os.path.join(ETSConfig.application_data,
                                 'mayavi_e3', 'mayavi-test.log')
             path = os.path.abspath(path)
+            log_path = os.path.dirname(path)
+            if not os.path.exists(log_path):
+                os.makedirs(log_path)
         else:
             path = 'mayavi-test.log'
         setup_logger(logger, path, mode=self.log_mode)
@@ -351,6 +492,7 @@ class TestCase(Mayavi):
             engine = Engine()
         engine.start()
 
+        self.exception_info = None
         self.script = Script(engine=engine)
         self.gui = g = GUI()
         self.app_window = a = ApplicationWindow()
@@ -358,46 +500,57 @@ class TestCase(Mayavi):
         a.show(False)
         g.invoke_later(self.run)
         g.start_event_loop()
+        if self.exception_info is not None:
+            type, value, tb = self.exception_info
+            raise type, value, tb
+
 
     def run(self):
         """This starts everything up and runs the test.  Call main to
         run the test."""
-
         # Calls the users test code.
         try:
-            self.do()
-        except Exception, e:
-            # To mimic behavior of unittest.
-            sys.stderr.write('\nfailures=1\n')
-            type, value, tb = sys.exc_info()
-            info = traceback.extract_tb(tb)
-            filename, lineno, function, text = info[-1] # last line only
-            exc_msg = "%s\nIn %s:%d\n%s: %s (in %s)" %\
-                      ('Exception', filename, lineno, type.__name__, str(value),
-                       function)
-            sys.stderr.write(exc_msg + '\n')
-            # Log the message.
-            logger.exception(exc_msg)
-            if not self.interact:
-                sys.exit(1)
-
-        if not self.interact:
-            if self.standalone:
-                # Close all existing viewers.
-                e = self.script.engine
-                for scene in e.scenes:
-                    viewer = e.get_viewer(scene)
-                    if viewer is not None:
-                        if self.offscreen:
-                            viewer.scene.close()
-                        else:
-                            viewer.close()
-                GUI.process_events()
-                # Shut down the app and the event loop.
-                self.app_window.close()
-                self.gui.stop_event_loop()
+            if self.profile:
+                memory_assistant = MemoryAssistant()
+                memory_assistant.assertReturnsMemory(self.do_profile,
+                                                     slack = 1.0)
             else:
-                self.application.gui.invoke_later(self.application.exit)
+                self.do()
+        except Exception, e:
+            type, value, tb = sys.exc_info()
+            if is_running_with_nose():
+                self.exception_info = type, value, tb
+            else:
+                # To mimic behavior of unittest.
+                sys.stderr.write('\nfailures=1\n')
+                info = traceback.extract_tb(tb)
+                filename, lineno, function, text = info[-1] # last line only
+                exc_msg = "%s\nIn %s:%d\n%s: %s (in %s)" %\
+                        ('Exception', filename, lineno, type.__name__, str(value),
+                        function)
+                sys.stderr.write(exc_msg + '\n')
+                # Log the message.
+                logger.exception(exc_msg)
+                if not self.interact:
+                    sys.exit(1)
+        finally:
+            if not self.interact:
+                if self.standalone:
+                    # Close all existing viewers.
+                    e = self.script.engine
+                    for scene in e.scenes:
+                        viewer = e.get_viewer(scene)
+                        if viewer is not None:
+                            if self.offscreen:
+                                viewer.scene.close()
+                            else:
+                                viewer.close()
+                    GUI.process_events()
+                    # Shut down the app and the event loop.
+                    self.app_window.close()
+                    self.gui.stop_event_loop()
+                else:
+                    self.application.gui.invoke_later(self.application.exit)
 
     def parse_command_line(self, argv):
         """Parse command line options."""
@@ -408,6 +561,10 @@ class TestCase(Mayavi):
         parser.add_option("-i", "--interact", action="store_true",
                           dest="interact", default=False,
                           help="Allow interaction after test (default: False)")
+        parser.add_option("-p", "--profile", action="store_true",
+                          dest="profile", default=False,
+                          help="Profile for memory usage and leaks "\
+                               "(default:False). [Long Running] ")
         parser.add_option("-s", "--nostandalone", action="store_true",
                           dest="standalone", default=False,
                           help="Run test using envisage without standalone "\
@@ -424,6 +581,7 @@ class TestCase(Mayavi):
             self.log_mode = logging.DEBUG
         self.offscreen = options.offscreen
         self.interact = options.interact
+        self.profile = options.profile
         self.standalone = not options.standalone
 
     ######################################################################
@@ -440,6 +598,16 @@ class TestCase(Mayavi):
         """
         raise NotImplementedError
 
+    def do_profile(self):
+        """Override this to profile for memory usage.
+
+        *Make sure all other MayaVi specific imports are made here!*
+
+        If you import MayaVi related code earlier you will run into
+        difficulties.
+        """
+        raise NotImplementedError
+
     def new_scene(self):
         """Creates a new TVTK scene, sets its size to that prescribed
         and returns the scene.
@@ -533,4 +701,3 @@ def test(function):
 
     test = MyTest()
     return test
-
