@@ -164,6 +164,13 @@ class PLOT3DReader(Source):
         self.reader.update()
         self.render()
 
+    def has_output_port(self):
+        """ Return True as the reader has output port."""
+        return True
+
+    def get_output_object(self):
+        """ Return the reader output port."""
+        return self.reader.output_port
 
     ######################################################################
     # Non-public interface
