@@ -34,9 +34,9 @@ class TestMGlyphSource(unittest.TestCase):
         """Check if the sources traits are set correctly."""
         x, y, z, v, s, src = self.get_data()
         # Check if points are set correctly.
-        self.assertEqual(N.alltrue(src.points[:,0].ravel() == x), True)
-        self.assertEqual(N.alltrue(src.points[:,1].ravel() == y), True)
-        self.assertEqual(N.alltrue(src.points[:,2].ravel() == z), True)
+        self.assertEqual(N.alltrue(src.points[:,0].ravel() == x.ravel()), True)
+        self.assertEqual(N.alltrue(src.points[:,1].ravel() == y.ravel()), True)
+        self.assertEqual(N.alltrue(src.points[:,2].ravel() == z.ravel()), True)
         # Check the vectors and scalars.
         self.assertEqual(N.alltrue(src.vectors == v), True)
         self.assertEqual(N.alltrue(src.scalars == s), True)
@@ -46,13 +46,13 @@ class TestMGlyphSource(unittest.TestCase):
         x, y, z, v, s, src = self.get_data()
         # Check if the dataset is setup right.
         pts = src.dataset.points.to_array()
-        self.assertEqual(N.alltrue(pts[:,0].ravel() == x), True)
-        self.assertEqual(N.alltrue(pts[:,1].ravel() == y), True)
-        self.assertEqual(N.alltrue(pts[:,2].ravel() == z), True)
+        self.assertEqual(N.alltrue(pts[:,0].ravel() == x.ravel()), True)
+        self.assertEqual(N.alltrue(pts[:,1].ravel() == y.ravel()), True)
+        self.assertEqual(N.alltrue(pts[:,2].ravel() == z.ravel()), True)
         vec = src.dataset.point_data.vectors.to_array()
         sc = src.dataset.point_data.scalars.to_array()
         self.assertEqual(N.alltrue(vec == v), True)
-        self.assertEqual(N.alltrue(sc == s), True)
+        self.assertEqual(N.alltrue(sc == s.ravel()), True)
 
     def test_reset(self):
         "Test the reset method."
@@ -62,7 +62,7 @@ class TestMGlyphSource(unittest.TestCase):
 
         # Call reset again with just a few things changed to see if it
         # works correctly.
-        x *= 5.0
+        x *= 5
         s *= 10
         v *= 0.1
         src.reset(x=x, u=v[:,0], v=v[:,1], w=v[:,2], scalars=s)
@@ -90,14 +90,30 @@ class TestMGlyphSource(unittest.TestCase):
         self.check_traits()
         self.check_dataset()
 
+    def test_reset_strange_shape(self):
+        " Test the reset method when the inputs are 2-d arrays."
+
+        x, y, z, v, s, src = self.get_data()
+        self.x = x = N.reshape(x, (5,2))
+        self.y = y = N.reshape(y, (5,2))
+        self.z = z = N.reshape(z, (5,2))
+        u = N.reshape(v[:,0], (5,2))
+        vv = N.reshape(v[:,1], (5,2))
+        w = N.reshape(v[:,2], (5,2))
+        self.s = s = N.reshape(s, (5,2))
+        src.reset(x=x, y=y, z=z, u=u, v=vv, w=w, scalars=s)
+        self.check_traits()
+        self.check_dataset()
+
+
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, z, v, s, src = self.get_data()
-        x *= 2.0
-        y *= 2.0
-        z *= 2.0
-        v *= 2.0
-        s *= 2.0
+        x *= 2
+        y *= 2
+        z *= 2
+        v *= 2
+        s *= 2
         src.x = x
         src.y = y
         src.z = z
@@ -108,12 +124,39 @@ class TestMGlyphSource(unittest.TestCase):
         self.check_traits()
         self.check_dataset()
 
+    def test_handlers_strange_shape(self):
+        "Test if the various static handlers work correctly for strange shapes."
+        # Initialize with 2-d array data.
+        x, y, z, v, s, src = self.get_data()
+        x = N.reshape(x, (5,2))
+        y = N.reshape(y, (5,2))
+        z = N.reshape(z, (5,2))
+        u = N.reshape(v[:,0], (5,2))
+        vv = N.reshape(v[:,1], (5,2))
+        w = N.reshape(v[:,2], (5,2))
+        s = N.reshape(s, (5,2))
+        src.reset(x=x, y=y, z=z, u=u, v=vv, w=w, scalars=s)
+
+        # modify variables in src to check handlers
+        self.x = src.x = 2*x
+        self.y = src.y = 2*y
+        self.z = src.z = 2*z
+        src.u = 2*z
+        src.v = 2*vv
+        src.w = 2*w
+        self.v[:,0] = src.u.ravel()
+        self.v[:,1] = src.v.ravel()
+        self.v[:,2] = src.w.ravel()
+        self.s = src.scalars = 2*s
+        self.check_traits()
+        self.check_dataset()
+
     def test_set(self):
         "Test if the set method works correctly."
         x, y, z, v, s, src = self.get_data()
-        x *= 2.0
-        z *= 2.0
-        s *= 2.0
+        x *= 2
+        z *= 2
+        s *= 2
         src.set(x=x, z=z, scalars=s)
         self.check_traits()
         self.check_dataset()
@@ -182,7 +225,7 @@ class TestMVerticalSource(unittest.TestCase):
 
         # Call reset again with just a few things changed to see if it
         # works correctly.
-        x *= 5.0
+        x *= 5
         s *= 10
         src.reset(x=x, scalars=s)
 
@@ -211,10 +254,10 @@ class TestMVerticalSource(unittest.TestCase):
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, z, s, src = self.get_data()
-        x *= 2.0
-        y *= 2.0
-        z *= 2.0
-        s *= 2.0
+        x *= 2
+        y *= 2
+        z *= 2
+        s *= 2
         src.x = x
         src.y = y
         src.z = z
@@ -225,9 +268,9 @@ class TestMVerticalSource(unittest.TestCase):
     def test_set(self):
         "Test if the set method works correctly."
         x, y, z, s, src = self.get_data()
-        x *= 2.0
-        z *= 2.0
-        s *= 2.0
+        x *= 2
+        z *= 2
+        s *= 2
         src.set(x=x, z=z, scalars=s)
         self.check_traits()
         self.check_dataset()
@@ -298,7 +341,7 @@ class TestMArraySource(unittest.TestCase):
 
         # Call reset again with just a few things changed to see if it
         # works correctly.
-        x *= 5.0
+        x *= 5
         s *= 10
         v *= 0.1
         src.reset(x=x, u=v[...,0], v=v[...,1], w=v[...,2], scalars=s)
@@ -332,11 +375,11 @@ class TestMArraySource(unittest.TestCase):
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, z, v, s, src = self.get_data()
-        x *= 2.0
-        y *= 2.0
-        z *= 2.0
-        v *= 2.0
-        s *= 2.0
+        x *= 2
+        y *= 2
+        z *= 2
+        v *= 2
+        s *= 2
         src.x = x
         src.y = y
         src.z = z
@@ -350,9 +393,9 @@ class TestMArraySource(unittest.TestCase):
     def test_set(self):
         "Test if the set method works correctly."
         x, y, z, v, s, src = self.get_data()
-        x *= 2.0
-        z *= 2.0
-        s *= 2.0
+        x *= 2
+        z *= 2
+        s *= 2
         src.set(x=x, z=z, scalars=s)
         self.check_traits()
         self.check_dataset()
@@ -407,14 +450,14 @@ class TestMLineSource(unittest.TestCase):
 
         # Call reset again with just a few things changed to see if it
         # works correctly.
-        x *= 5.0
+        x *= 5
         s *= 10
         src.reset(x=x, scalars=s)
 
         self.check_traits()
         self.check_dataset()
 
-        y *= 6.0
+        y *= 6
         x *= 4
         src.reset(x=x, y=y)
 
@@ -452,10 +495,10 @@ class TestMLineSource(unittest.TestCase):
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, z, s, src = self.get_data()
-        x *= 2.0
-        y *= 2.0
-        z *= 2.0
-        s *= 2.0
+        x *= 2
+        y *= 2
+        z *= 2
+        s *= 2
         src.x = x
         src.y = y
         src.z = z
@@ -466,16 +509,15 @@ class TestMLineSource(unittest.TestCase):
     def test_set(self):
         "Test if the set method works correctly."
         x, y, z, s, src = self.get_data()
-        x *= 2.0
-        z *= 2.0
-        s *= 2.0
+        x *= 2
+        z *= 2
+        s *= 2
         src.set(x=x, z=z, scalars=s)
         self.check_traits()
         self.check_dataset()
 
-
-        y *= 2.0
-        s *= 2.0
+        y *= 2
+        s *= 2
         src.set(y=y, scalars=s)
         self.check_traits()
         self.check_dataset()
@@ -542,7 +584,7 @@ class TestMArray2DSource(unittest.TestCase):
 
         # Call reset again with just a few things changed to see if it
         # works correctly.
-        x *= 5.0
+        x *= 5
         s *= 10
         src.reset(x=x,y=y, scalars=s)
 
@@ -553,9 +595,9 @@ class TestMArray2DSource(unittest.TestCase):
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, s, src = self.get_data()
-        x *= 2.0
-        y *= 2.0
-        s *= 2.0
+        x *= 2
+        y *= 2
+        s *= 2
         src.x = x
         src.y = y
         src.scalars = s
@@ -567,16 +609,16 @@ class TestMArray2DSource(unittest.TestCase):
     def test_set(self):
         "Test if the set method works correctly."
         x, y, s, src  = self.get_data()
-        x *= 2.0
-        s *= 2.0
+        x *= 2
+        s *= 2
         src.set(x=x,scalars=s)
 
 
         self.check_traits()
         self.check_dataset()
 
-        y *= 9.0
-        s *= 2.0
+        y *= 9
+        s *= 2
         src.set(y=y, scalars=s)
         self.check_traits()
         self.check_dataset()
@@ -633,7 +675,7 @@ class TestMGridSource(unittest.TestCase):
 
         # Call reset again with just a few things changed to see if it
         # works correctly.
-        x *= 5.0
+        x *= 5
         s *= 10
 
         src.reset(x=x, scalars=s)
@@ -643,10 +685,10 @@ class TestMGridSource(unittest.TestCase):
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, z, s, src = self.get_data()
-        x *= 2.0
-        y *= 2.0
-        z *= 2.0
-        s *= 2.0
+        x *= 2
+        y *= 2
+        z *= 2
+        s *= 2
         src.x = x
         src.y = y
         src.z = z
@@ -657,9 +699,9 @@ class TestMGridSource(unittest.TestCase):
     def test_set(self):
         "Test if the set method works correctly."
         x, y, z, s, src = self.get_data()
-        x *= 2.0
-        z *= 2.0
-        s *= 2.0
+        x *= 2
+        z *= 2
+        s *= 2
         src.set(x=x, z=z, scalars=s)
         self.check_traits()
         self.check_dataset()
@@ -753,7 +795,7 @@ class TestMArray2DSourceNoArgs(unittest.TestCase):
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, s, src = self.get_data()
-        s *= 2.0
+        s *= 2
         src.scalars = s
 
         self.check_traits()
@@ -763,7 +805,7 @@ class TestMArray2DSourceNoArgs(unittest.TestCase):
     def test_set(self):
         "Test if the set method works correctly."
         x, y, s, src = self.get_data()
-        s *= 2.0
+        s *= 2
         src.set(x=x,y=y,scalars=s)
 
         self.check_traits()
@@ -809,7 +851,7 @@ class TestMTriangularMeshSource(unittest.TestCase):
 
         # Call reset again with just a few things changed to see if it
         # works correctly.
-        x *= 5.0
+        x *= 5
         s *= 10
         src.reset(x=x,y=y,z=z, triangles=triangles, scalars=s)
 
@@ -832,9 +874,9 @@ class TestMTriangularMeshSource(unittest.TestCase):
     def test_handlers(self):
         "Test if the various static handlers work correctly."
         x, y, z, triangles, s, src = self.get_data()
-        x *= 2.0
-        y *= 2.0
-        s *= 2.0
+        x *= 2
+        y *= 2
+        s *= 2
         src.x = x
         src.y = y
         src.scalars = s
@@ -846,14 +888,14 @@ class TestMTriangularMeshSource(unittest.TestCase):
     def test_set(self):
         "Test if the set method works correctly."
         x, y, z, triangles, s, src = self.get_data()
-        x *= 2.0
-        s *= 2.0
+        x *= 2
+        s *= 2
         src.set(x=x,scalars=s)
 
         self.check_traits()
 
-        y *= 9.0
-        s *= 2.0
+        y *= 9
+        s *= 2
         src.set(y=y, scalars=s)
 
         self.check_traits()
