@@ -27,6 +27,7 @@ import numpy
 
 # Enthought library imports.
 from tvtk.array_ext import set_id_type_array
+from tvtk.common import is_old_pipeline
 
 # Useful constants for VTK arrays.
 VTK_ID_TYPE_SIZE = vtk.vtkIdTypeArray().GetDataTypeSize()
@@ -382,21 +383,33 @@ def vtk2array(vtk_array):
     else:
         img_data.GetPointData().SetScalars(vtk_array)
 
-    img_data.SetNumberOfScalarComponents(shape[1])
-    if typ == vtkConstants.VTK_ID_TYPE:
-        # Hack necessary because vtkImageData can't handle VTK_ID_TYPE.
-        img_data.SetScalarType(vtkConstants.VTK_LONG)
-        r_dtype = get_numeric_array_type(vtkConstants.VTK_LONG)
-    elif typ == vtkConstants.VTK_BIT:
-        img_data.SetScalarType(vtkConstants.VTK_CHAR)
-        r_dtype = get_numeric_array_type(vtkConstants.VTK_CHAR)
+    if is_old_pipeline():
+        img_data.SetNumberOfScalarComponents(shape[1])
+        if typ == vtkConstants.VTK_ID_TYPE:
+            # Hack necessary because vtkImageData can't handle VTK_ID_TYPE.
+            img_data.SetScalarType(vtkConstants.VTK_LONG)
+            r_dtype = get_numeric_array_type(vtkConstants.VTK_LONG)
+        elif typ == vtkConstants.VTK_BIT:
+            img_data.SetScalarType(vtkConstants.VTK_CHAR)
+            r_dtype = get_numeric_array_type(vtkConstants.VTK_CHAR)
+        else:
+            img_data.SetScalarType(typ)
+            r_dtype = get_numeric_array_type(typ)
+        img_data.Update()
     else:
-        img_data.SetScalarType(typ)
-        r_dtype = get_numeric_array_type(typ)
-    img_data.Update()
+        if typ == vtkConstants.VTK_ID_TYPE:
+            r_dtype = get_numeric_array_type(vtkConstants.VTK_LONG)
+        elif typ == vtkConstants.VTK_BIT:
+            r_dtype = get_numeric_array_type(vtkConstants.VTK_CHAR)
+        else:
+            r_dtype = get_numeric_array_type(typ)
+        img_data.Modified()
 
     exp = vtk.vtkImageExport()
-    exp.SetInput(img_data)
+    if is_old_pipeline():
+        exp.SetInput(img_data)
+    else:
+        exp.SetInputData(img_data)
 
     # Create an array of the right size and export the image into it.
     im_arr = numpy.empty((shape[0]*shape[1],), r_dtype)
@@ -759,4 +772,3 @@ def deref_array(args, sigs=None):
             else:
                 ret.append(deref_vtk(a))
     return ret
-
