@@ -564,6 +564,15 @@ class Scene(TVTKScene, Widget):
         self._interacting = False
         self._vtk_control.OnButtonUp(event)
 
+    ###########################################################################
+    # 'event' interface.
+    ###########################################################################
+
+    def _closed_fired(self):
+        super(Scene, self)._closed_fired()
+        self.picker = None
+        self._vtk_control = None
+
     ###########################################################################
     # Non-public interface.
     ###########################################################################
