@@ -124,7 +124,8 @@ class SpecialGenerator:
         code = """
         def __getstate__(self):
             d = tvtk_base.TVTKBase.__getstate__(self)
-            del d['color']
+            if 'color' in d:
+                del d['color']
             return d
 
         def __setstate__(self, dict):
@@ -318,8 +319,11 @@ class SpecialGenerator:
                 yield obj.GetPoint(i)
 
         def _check_key(self, key, n):
-            if type(key) != type(1):
-                raise TypeError, "Only integers are valid keys."
+            ##############################################
+            # Allow int and long keys. Fixes GH Issue 173.
+            ##############################################
+            if not isinstance(key, (int, long)):
+                raise TypeError, "Only int and long are valid keys."
             if key < 0:
                 key =  n + key
             if key < 0 or key >= n:
@@ -548,4 +552,3 @@ class HelperGenerator:
         %(name)s = property(lambda self: get_class('%(name)s'))
         """%locals()
         out.write(self.indent.format(code))
-
