@@ -63,6 +63,7 @@ from traitsui.api import View, Item, Group, RGBColorEditor, RangeEditor
 from traitsui.message import message
 from tvtk.api import tvtk
 from tvtk.tools import ivtk
+from tvtk.common import configure_input_data
 from pyface.api import GUI
 from pyface.timer.api import Timer
 from tvtk.tvtk_base import TVTKBase, vtk_color_trait
@@ -584,14 +585,17 @@ class Curve(HasTraits):
         self._radius_changed(self.radius)
         self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
 
-        self.stripper.input = self.polydata
-        self.tube.input = self.stripper.output
+        configure_input_data(self.stripper, self.polydata)
+        configure_input_data(self.tube, self.stripper.output)
         self.tube.number_of_sides = 4
         self.tube.capping = 1
 
         m = tvtk.PolyDataMapper()
-        m.input = self.tube.output
+        configure_input_data(m, self.tube.output)
         self.actor.mapper = m
+        self.stripper.update()
+        self.tube.update()
+        self.actor.mapper.update()
         self.property = self.actor.property
         self.property.representation = self.representation
         show_actor(self.actor)
@@ -621,6 +625,9 @@ class Curve(HasTraits):
 
     def update(self):
         self.polydata.modified()
+        self.stripper.update()
+        self.tube.update()
+        self.actor.mapper.update()
         self.viewer.scene.render()
 
     def rotate(self, angle, axis, origin = numpy.array([0.0, 0.0, 0.0])):
@@ -634,6 +641,9 @@ class Curve(HasTraits):
         self.set(axis = ax, trait_change_notify = False)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.stripper.update()
+        self.tube.update()
+        self.actor.mapper.update()
         self.render()
 
     def render(self):
@@ -655,6 +665,9 @@ class Curve(HasTraits):
             lines[:,0] = numpy.arange(0, np-0.5, 1, 'l')
             lines[:,1] = numpy.arange(1, np+0.5, 1, 'l')
         self.polydata.lines = lines
+        self.polydata.modified()
+        self.stripper.update()
+        self.tube.update()
         v = self.viewer
         if v is not None:
             v.scene.render()
@@ -679,12 +692,17 @@ class Curve(HasTraits):
         self.set(points = p, trait_change_notify = False)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.stripper.update()
+        self.tube.update()
+        self.actor.mapper.update()
         self.render()
 
     def _axis_changed(self, old, new):
         self.points = axis_changed(old, new, self.pos, self.points)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.stripper.update()
+        self.tube.update()
         self.render()
 
     def _color_changed(self, value):
@@ -728,6 +746,7 @@ class Ring(HasTraits):
     property = Instance(tvtk.Property)
     tube = Instance(tvtk.TubeFilter, ())
     actor = Instance(tvtk.Actor, ()) # tvtk Actor, for the usual pipeline architecture.
+    normals = Instance(tvtk.PolyDataNormals(), ())
 
     ######################################################################
     # User interface view
@@ -760,13 +779,16 @@ class Ring(HasTraits):
         self._thickness_changed(self.thickness)
         self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
 
-        normals = tvtk.PolyDataNormals(input = self.polydata)
-        self.tube.input = normals.output
+        self.normals = tvtk.PolyDataNormals()
+        configure_input_data(self.normals, self.polydata)
+        configure_input_data(self.tube, self.normals.outputs)
+        self.normals.update()
+        self.tube.update()
         self.tube.number_of_sides = 4
         self.tube.capping = 1
 
         m = tvtk.PolyDataMapper()
-        m.input = self.tube.output
+        configure_input_data(m, self.tube.outputs)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -805,6 +827,9 @@ class Ring(HasTraits):
         if (numpy.allclose(self.pos, 0.0)):
             self.points[:] = factor*self.points[:]
             self.polydata.modified()
+            self.normals.update()
+            self.tube.update()
+            self.actor.mapper.update()
             self.render()
         else:
             c = self.pos
@@ -815,6 +840,9 @@ class Ring(HasTraits):
             self.points = translate_points(diff, self.points)
             self.polydata.points = self.points
             self.polydata.modified()
+            self.normals.update()
+            self.actor.mapper.update()
+            self.tube.update()
             self.render()
 
     def _x_changed(self, value):
@@ -836,12 +864,17 @@ class Ring(HasTraits):
         self.points = translate(old, new, self.points)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
+        self.actor.mapper.update()
         self.render()
 
     def _axis_changed(self, old, new):
         self.points = axis_changed(old, new, self.pos, self.points)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
         self.render()
 
     def _representation_changed(self, value):
@@ -872,6 +905,9 @@ class Ring(HasTraits):
         self.set(axis = ax, trait_change_notify = False)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
+        self.actor.mapper.update()
         self.render()
 
     def render(self):
@@ -935,7 +971,7 @@ class Cone(HasTraits):
         self._color_changed(self.color)
 
         m = tvtk.PolyDataMapper()
-        m.input = self.polydata
+        configure_input_data(m, self.polydata)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -965,12 +1001,14 @@ class Cone(HasTraits):
         points, lines = self._create_points(self.radius, self.height, self.pos, self.axis)
         self.polydata.points = points
         self.polydata.modified()
+        self.actor.mapper.update()
         self.render()
 
     def _height_changed(self):
         points, lines = self._create_points(self.radius, self.height, self.pos, self.axis)
         self.polydata.points = points
         self.polydata.modified()
+        self.actor.mapper.update()
         self.render()
 
     def _pos_changed(self, old, new):
@@ -980,6 +1018,7 @@ class Cone(HasTraits):
         points, lines = self._create_points(self.radius, self.height, self.pos, self.axis)
         self.points = points
         self.polydata.modified()
+        self.actor.mapper.update()
         self.render()
 
     def _axis_changed(self):
@@ -1025,6 +1064,7 @@ class Cone(HasTraits):
         self.set(axis = ax, trait_change_notify = False)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.actor.mapper.update()
         self.render()
 
     def render(self):
@@ -1054,6 +1094,7 @@ class Sphere(HasTraits):
     polydata = Instance(tvtk.PolyData, ())
     property = Instance(tvtk.Property)
     actor = Instance(tvtk.Actor, ()) # tvtk Actor, for the usual pipeline architecture.
+    normals = Instance(tvtk.PolyDataNormals, ())
 
     ######################################################################
     # User interface view
@@ -1082,8 +1123,11 @@ class Sphere(HasTraits):
         self._y_changed(self.y)
         self._z_changed(self.z)
 
-        normals = tvtk.PolyDataNormals(input = self.polydata)
-        m = tvtk.PolyDataMapper(input = normals.output) # the usual vtk pipleine countinuation
+        self.normals = tvtk.PolyDataNormals()
+        configure_input_data(self.normals, self.polydata)
+        self.normals.update()
+        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
+        configure_input_data(m, self.normals.output)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -1096,7 +1140,9 @@ class Sphere(HasTraits):
     ######################################################################
     # Non-public methods, Event handlers
     def _create_points(self, r, c):
-        sp = tvtk.SphereSource(radius = r, center = tuple(c), phi_resolution = 20, theta_resolution = 20)
+        sp = tvtk.SphereSource(radius = r, center = tuple(c), 
+                               phi_resolution = 20, 
+                               theta_resolution = 20)
         sp.update()
         ps = sp.output
 
@@ -1122,12 +1168,14 @@ class Sphere(HasTraits):
         points, lines = self._create_points(self.radius, self.pos)
         self.polydata.points = points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _axis_changed(self, old, new):
         self.points = axis_changed(old, new, self.pos, self.points)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _x_changed(self, value):
@@ -1199,6 +1247,7 @@ class Cylinder(HasTraits):
     polydata = Instance(tvtk.PolyData, ())
     actor = Instance(tvtk.Actor, ()) # tvtk Actor, for the usual pipeline architecture.
     property = Instance(tvtk.Property)
+    normals = Instance(tvtk.PolyDataNormals(), ())
 
     ######################################################################
     # User interface view
@@ -1229,8 +1278,10 @@ class Cylinder(HasTraits):
         self._y_changed(self.y)
         self._z_changed(self.z)
 
-        normals = tvtk.PolyDataNormals(input = self.polydata)
-        m = tvtk.PolyDataMapper(input = normals.output) # the usual vtk pipleine countinuation
+        self.normals = tvtk.PolyDataNormals()
+        configure_input_data(self.normals, self.polydata)
+        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
+        configure_input_data(m, self.normals.output)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -1261,18 +1312,21 @@ class Cylinder(HasTraits):
         self.points, polys = self._create_points(self.radius, self.pos, self.length)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _length_changed(self, value):
         self.points, polys = self._create_points(self.radius, self.pos, self.length)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _axis_changed(self, old, new):
         self.points = axis_changed(old, new, self.pos, self.points)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _pos_changed(self, old, new):
@@ -1282,6 +1336,7 @@ class Cylinder(HasTraits):
         self.points = translate(old, new, self.points)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _color_changed(self, value):
@@ -1324,6 +1379,7 @@ class Cylinder(HasTraits):
         self.set(axis = ax, trait_change_notify = False)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def render(self):
@@ -1392,7 +1448,7 @@ class Box(HasTraits):
         self._width_changed(self.width)
 
         m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
-        m.input = self.polydata
+        configure_input_data(m, self.polydata)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -1520,6 +1576,7 @@ class Arrow(HasTraits):
     actor = Instance(tvtk.Actor, ()) # tvtk Actor, for the usual pipeline architecture.
     property = Instance(tvtk.Property)
     polydata = Instance(tvtk.PolyData, ())
+    normals = Instance(tvtk.PolyDataNormals(), ())
 
     ######################################################################
     # User interface view
@@ -1550,8 +1607,11 @@ class Arrow(HasTraits):
         self._z_changed(self.z)
         self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
 
-        normals = tvtk.PolyDataNormals(input = self.polydata)
-        m = tvtk.PolyDataMapper(input = normals.output) # the usual vtk pipleine countinuation
+        self.normals = tvtk.PolyDataNormals()
+        configure_input_data(self.normals, self.polydata)
+        self.normals.update()
+        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
+        configure_input_data(m, self.normals.output)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -1578,18 +1638,21 @@ class Arrow(HasTraits):
         self.points, polys = self._create_points(self.radius_cone, self.length_cone, self.radius_shaft, self.pos)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _length_cone_changed(self, old, new):
         self.points, polys = self._create_points(self.radius_cone, self.length_cone, self.radius_shaft, self.pos)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _radius_shaft_changed(self, old, new):
         self.points, polys = self._create_points(self.radius_cone, self.length_cone, self.radius_shaft, self.pos)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _pos_changed(self, old, new):
@@ -1599,12 +1662,14 @@ class Arrow(HasTraits):
         self.points = translate(old, new, self.points)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _axis_changed(self, old, new):
         self.points = axis_changed(old, new, self.pos, self.points)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _color_changed(self, value):
@@ -1647,6 +1712,7 @@ class Arrow(HasTraits):
         self.set(axis = ax, trait_change_notify = False)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def render(self):
@@ -1682,6 +1748,7 @@ class Helix(HasTraits):
     property = Instance(tvtk.Property)
     tube = Instance(tvtk.TubeFilter, ())
     actor = Instance(tvtk.Actor, ()) # tvtk Actor, for the usual pipeline architecture.
+    normals = Instance(tvtk.PolyDataNormals(), ())
 
     ######################################################################
     # User interface view
@@ -1713,13 +1780,14 @@ class Helix(HasTraits):
         self._thickness_changed(self.thickness)
         self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
 
-        normals = tvtk.PolyDataNormals(input = self.polydata)
-        self.tube.input = normals.output
+        self.normals = tvtk.PolyDataNormals()
+        configure_input_data(self.normals, self.polydata)
+        configure_input_data(self.tube, self.normals.output)
         self.tube.number_of_sides = 4
         self.tube.capping = 1
 
         m = tvtk.PolyDataMapper()
-        m.input = self.tube.output
+        configure_input_data(m, self.tube.output)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -1751,6 +1819,8 @@ class Helix(HasTraits):
         lines[:,1] = numpy.arange(1, np+0.5, 1, 'l')
         self.polydata.points = self.points
         self.polydata.lines = lines
+        self.normals.update()
+        self.tube.update()
 
     def _color_changed(self, value):
         self.actor.property.color = value
@@ -1761,6 +1831,8 @@ class Helix(HasTraits):
         self.change_axis(numpy.array((1.0, 0.0, 0.0)), self.axis)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
         self.render()
 
     def _coils_changed(self, old, new):
@@ -1787,6 +1859,8 @@ class Helix(HasTraits):
         self._pos_changed(numpy.array([0.0, 0.0, 0.0]), self.pos)
         self.change_axis(numpy.array((1.0, 0.0, 0.0)), self.axis)
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
         self.render()
 
     def _x_changed(self, value):
@@ -1813,12 +1887,16 @@ class Helix(HasTraits):
         self.points = translate(old, new, self.points)
         #self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
         self.render()
 
     def _axis_changed(self, old, new):
         self.points = axis_changed(old, new, self.pos, self.points)
         #self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
         self.render()
 
     def change_axis(self, old, new):
@@ -1836,6 +1914,8 @@ class Helix(HasTraits):
             v.scene.disable_render = False
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
         self.render()
 
     def _visibility_changed(self, value):
@@ -1861,6 +1941,8 @@ class Helix(HasTraits):
         self.set(axis = ax, trait_change_notify = False)
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
+        self.tube.update()
         self.render()
 
     def render(self):
@@ -1895,6 +1977,7 @@ class Ellipsoid(HasTraits):
     polydata = Instance(tvtk.PolyData, ())
     property = Instance(tvtk.Property)
     actor = Instance(tvtk.Actor, ()) # tvtk Actor, for the usual pipeline architecture.
+    normals = Instance(tvtk.PolyDataNormals(), ())
 
     ######################################################################
     # User interface view
@@ -1925,8 +2008,11 @@ class Ellipsoid(HasTraits):
         self._z_changed(self.z)
         self._axis_changed(numpy.array((1.0, 0.0, 0.0)), self.axis)
 
-        normals = tvtk.PolyDataNormals(input = self.polydata)
-        m = tvtk.PolyDataMapper(input = normals.output) # the usual vtk pipleine countinuation
+        self.normals = tvtk.PolyDataNormals()
+        configure_input_data(self.normals, self.polydata)
+        self.normals.update()
+        m = tvtk.PolyDataMapper() # the usual vtk pipleine countinuation
+        configure_input_data(self.normals, self.normals.output)
         self.actor.mapper = m
         self.property = self.actor.property
         self.property.representation = self.representation
@@ -1954,12 +2040,14 @@ class Ellipsoid(HasTraits):
         points, polys = self._create_points(self.radius, self.pos)
         self.polydata.points = points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _size_changed(self, value):
         points, polys = self._create_points(self.radius, self.pos)
         self.polydata.points = points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _color_changed(self, value):
@@ -1972,6 +2060,7 @@ class Ellipsoid(HasTraits):
         points, lines = self._create_points(self.radius, self.pos)
         self.polydata.points = points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _axis_changed(self, old, new):
@@ -1979,6 +2068,7 @@ class Ellipsoid(HasTraits):
         self.points = points
         self.polydata.points = self.points
         self.polydata.modified()
+        self.normals.update()
         self.render()
 
     def _x_changed(self, value):
