@@ -7,11 +7,12 @@ type information, and organizes them.
 # License: BSD Style.
 
 import re
+import types
 
 # Local imports (these are relative imports for a good reason).
 import class_tree
 import vtk_module as vtk
-
+from common import is_version_62
 
 class VTKMethodParser:
     """This class provides useful methods for parsing methods of a VTK
@@ -299,6 +300,12 @@ class VTKMethodParser:
           A VTK method object.
 
         """
+        # VTK 6.2 false built in funcs/methods are ignored
+        if is_version_62():
+            built_in_func = isinstance(method, types.BuiltinFunctionType)
+            built_in_meth = isinstance(method, types.BuiltinMethodType)
+            if not (built_in_func or built_in_meth):
+                return None
         # Remove all the C++ function signatures.
         doc = method.__doc__
         doc = doc[:doc.find('\n\n')]
@@ -475,6 +482,8 @@ class VTKMethodParser:
             if klass_name == 'vtkDataSetAttributes' and \
                method[:-2] in problem_methods:
                 continue
+            elif method[:-2] == 'AlphaBitPlanes':
+                continue
             if method[-2:] == 'On':
                 key = method[:-2]
                 if (key + 'Off') in meths and ('Get' + key) in meths:
@@ -586,6 +595,20 @@ class VTKMethodParser:
                 # vtkProp.Get/SetAllocatedRenderTime is private and
                 # SetAllocatedRenderTime takes two args, don't wrap it.
                 continue
+            elif klass_name == 'vtkGenericAttributeCollection' and \
+                method[3:] == 'AttributesToInterpolate':
+                continue
+            elif klass_name == 'vtkOverlappingAMR' and method[3:] == 'Origin':
+                continue
+            elif (klass_name == 'vtkOrientationMarkerWidget'
+                  and method[3:] in ['OutlineColor', 'Viewport']):
+                continue
+            elif (klass_name == 'vtkImageDataGeometryFilter'
+                  and method[3:] == 'Extent'):
+                continue
+            elif (klass_name == 'vtkVolumeMapper'
+                  and method[3:] == 'CroppingRegionPlanes'):
+                continue
             elif (method[:3] == 'Set') and ('Get' + method[3:]) in methods:
                 key = method[3:]
                 meths.remove('Set' + key)
